%% General remarks.
%
% The bimodality coefficient (BC) is computed easily for any given
% dataset by using the functions 'skewness' and 'kurtosis'
% which are available via the statistics toolbox. Both functions
% are called with a flag argument of 0 to indicate that sample
% bias corrections should be performed.
%
% Assuming that the data are stored in a numeric vector of the
% name 'data', the BC can be computed in the following four
% steps:
%
%    m3 = skewness(data,0);
%    m4 = kurtosis(data,0)-3;
%    n  = length(data);
%    bc = (m3^2+1) / (m4 + 3 * ( (n-1)^2 / ((n-2)*(n-3)) ));
%
% This procedure is implemented for the data of figure A-F of the
% article in the following.

%% Fig. A-F 

% Define (x-) values.
clear x;
x = 1:11;

% Define frequencies (instead of writing the entire data).
clear y;
y(1,:) = [ 3,  5,  5, 10, 17, 20, 17, 10,  5,  5,  3];
y(2,:) = [ 2, 26, 14,  6,  2,  0,  2,  6, 14, 26,  2];
y(3,:) = [ 2,  3,  3,  3,  3,  4,  5, 11, 21, 41,  4];
y(4,:) = [ 2,  3,  6, 17,  3,  4,  5, 12, 14, 30,  4];

% Prepare analysis.
figure(1);
clear m3;
clear m4;
clear n;
clear bc;
bcflag = 0; % 0 = bias correction, 1 = no correction

for ifig = 1:4
    
    % Transform frequencies in an actual vector of raw data.
    data = [];
    for i = 1:numel(x)
        data = [data repmat(x(i),1,y(ifig,i))]; %#ok<AGROW>
    end;
    clear i;

    % Compute BC
    m3(ifig) = skewness(data,bcflag);
    m4(ifig) = kurtosis(data,bcflag)-3;
    n(ifig)  = length(data);
    bc(ifig) = (m3(ifig).^2+1) / (m4(ifig) + 3 * ...
        ( (n(ifig)-1).^2 / ((n(ifig)-2)*(n(ifig)-3)) ));
    
    % Plot histogram
    subplot(3,2,ifig);
    hist(data,11)
    title(['bc = ' num2str(bc(ifig))]);
    set(gca,'XLim',[0,12]);
    set(gca,'YLim',[0,45]);

end;
clear ifig;
clear bcflag;

% Display BCs
disp(bc);